pub struct MPCProver {
committer: PedersenCommitter<Bn256Point>,
converter: VandermondeInverse<Scalar>,
slope_commitments: [HyraxProverInputCommitment<Bn256Point>; 2],
prover_config: GKRCircuitProverConfig,
mpc_circuit_and_const_mles_all_3_parties: MPCCircuitsAndConstData<Fr>,
left_eye_proofs_all_3_parties: Option<Vec<HyraxProof<Bn256Point>>>,
right_eye_proofs_all_3_parties: Option<Vec<HyraxProof<Bn256Point>>>,
}Fields
committer: PedersenCommitter<Bn256Point>converter: VandermondeInverse<Scalar>slope_commitments: [HyraxProverInputCommitment<Bn256Point>; 2]prover_config: GKRCircuitProverConfigmpc_circuit_and_const_mles_all_3_parties: MPCCircuitsAndConstData<Fr>left_eye_proofs_all_3_parties: Option<Vec<HyraxProof<Bn256Point>>>right_eye_proofs_all_3_parties: Option<Vec<HyraxProof<Bn256Point>>>Implementations
Sourceimpl MPCProver
impl MPCProver
Computes a set of random Shamir secret share slopes and creates a Hyrax commitment for them.
Note that rng should be a CSPRNG seeded with a strong source of
device entropy! Recommended to call this with OsRng and ChaCha20Rng.
pub fn default_committer() -> PedersenCommitter<Bn256Point>
pub fn new( prover_config: GKRCircuitProverConfig, mpc_circuit_and_aux_mles_all_3_parties: MPCCircuitsAndConstData<Fr>, rng: &mut (impl CryptoRng + RngCore), ) -> Self
pub fn get_committer_ref(&self) -> &PedersenCommitter<Bn256Point>
pub fn prove_mpc_with_precommits( mpc_provable_circuit: HyraxProvableCircuit<Bn256Point>, iris_precommit: &HyraxProverInputCommitment<Bn256Point>, mask_precommit: &HyraxProverInputCommitment<Bn256Point>, slope_precommit: &HyraxProverInputCommitment<Bn256Point>, committer: &PedersenCommitter<Bn256Point>, blinding_rng: &mut (impl CryptoRng + RngCore), converter: &mut VandermondeInverse<Scalar>, ) -> HyraxProof<Bn256Point>
pub fn prove( &mut self, is_left_eye: bool, iris_code_precommit: HyraxProverInputCommitment<Bn256Point>, mask_code_precommit: HyraxProverInputCommitment<Bn256Point>, rng: &mut (impl CryptoRng + RngCore), )
Sourcepub fn set(
&mut self,
is_left_eye: bool,
proofs_all_3_parties: Vec<HyraxProof<Bn256Point>>,
)
pub fn set( &mut self, is_left_eye: bool, proofs_all_3_parties: Vec<HyraxProof<Bn256Point>>, )
Set the field indicated by is_mask and is_left_eye to proof,
overwritting any existing value.
Sourcepub fn set_left_proof(
&mut self,
proofs_all_3_parties: Vec<HyraxProof<Bn256Point>>,
)
pub fn set_left_proof( &mut self, proofs_all_3_parties: Vec<HyraxProof<Bn256Point>>, )
Set the left image proof to proof, overwritting any existing value.
Sourcepub fn set_right_proof(
&mut self,
proofs_all_3_parties: Vec<HyraxProof<Bn256Point>>,
)
pub fn set_right_proof( &mut self, proofs_all_3_parties: Vec<HyraxProof<Bn256Point>>, )
Set the right image proof to proof, overwritting any existing value.
pub fn is_set(&self, is_left_eye: bool) -> bool
Sourcefn is_ready_to_finalize(&self) -> bool
fn is_ready_to_finalize(&self) -> bool
Checks whether self is ready to be finalized, i.e. whether all 4
proofs are present.`
pub fn finalize(&self) -> Result<MPCProof, MPCProofError>