pub struct V3MPCProver {
v3_prover: V3Prover,
mpc_prover: MPCProver,
left_iris_commit: Option<HyraxProverInputCommitment<Bn256Point>>,
left_mask_commit: Option<HyraxProverInputCommitment<Bn256Point>>,
right_iris_commit: Option<HyraxProverInputCommitment<Bn256Point>>,
right_mask_commit: Option<HyraxProverInputCommitment<Bn256Point>>,
}Expand description
A Wrapper around the V3Prover and the MPCProver.
Includes the commitments to the iris / mask codes, so that the mpc4
circuits can use the pre-commitments as inputs.
Fields
v3_prover: V3ProverThe prover for the iris circuit.
mpc_prover: MPCProverThe prover for the mpc circuit.
left_iris_commit: Option<HyraxProverInputCommitment<Bn256Point>>The commitments to the iris / mask codes.
left_mask_commit: Option<HyraxProverInputCommitment<Bn256Point>>right_iris_commit: Option<HyraxProverInputCommitment<Bn256Point>>right_mask_commit: Option<HyraxProverInputCommitment<Bn256Point>>Implementations
Sourceimpl V3MPCProver
impl V3MPCProver
Sourcepub fn new(
prover_config: GKRCircuitProverConfig,
iris_circuit: V3CircuitAndAuxData<Fr>,
mpc_circuits: MPCCircuitsAndConstData<Fr>,
rng: &mut (impl CryptoRng + RngCore),
) -> Self
pub fn new( prover_config: GKRCircuitProverConfig, iris_circuit: V3CircuitAndAuxData<Fr>, mpc_circuits: MPCCircuitsAndConstData<Fr>, rng: &mut (impl CryptoRng + RngCore), ) -> Self
Generate an empty v3-mpc prover with the given configuration.
pub fn prove_v3( &mut self, is_mask: bool, is_left_eye: bool, image_bytes: Vec<u8>, image_precommit: HyraxProverInputCommitment<Bn256Point>, rng: &mut (impl CryptoRng + RngCore), )
pub fn prove_mpc( &mut self, is_left_eye: bool, rng: &mut (impl CryptoRng + RngCore), )
pub fn finalize(&self) -> Result<V3MPCProof, V3MPCProofError>
Sourcepub fn set_commit(
&mut self,
is_mask: bool,
is_left_eye: bool,
commitment: HyraxProverInputCommitment<Bn256Point>,
)
pub fn set_commit( &mut self, is_mask: bool, is_left_eye: bool, commitment: HyraxProverInputCommitment<Bn256Point>, )
Set the field indicated by is_mask and is_left_eye to proof,
overwritting any existing value.
Sourcepub fn set_commit_left_iris(
&mut self,
commitment: HyraxProverInputCommitment<Bn256Point>,
)
pub fn set_commit_left_iris( &mut self, commitment: HyraxProverInputCommitment<Bn256Point>, )
Set the left image commitment to commitment, overwritting any existing value.
Sourcepub fn set_commit_left_mask(
&mut self,
commitment: HyraxProverInputCommitment<Bn256Point>,
)
pub fn set_commit_left_mask( &mut self, commitment: HyraxProverInputCommitment<Bn256Point>, )
Set the left mask commitment to commitment, overwritting any existing value.
Sourcepub fn set_commit_right_iris(
&mut self,
commitment: HyraxProverInputCommitment<Bn256Point>,
)
pub fn set_commit_right_iris( &mut self, commitment: HyraxProverInputCommitment<Bn256Point>, )
Set the right image commitment to commitment, overwritting any existing value.
Sourcepub fn set_commit_right_mask(
&mut self,
commitment: HyraxProverInputCommitment<Bn256Point>,
)
pub fn set_commit_right_mask( &mut self, commitment: HyraxProverInputCommitment<Bn256Point>, )
Set the right mask commitment to commitment, overwritting any existing value.
Sourcepub fn get_commit(
&mut self,
is_mask: bool,
is_left_eye: bool,
) -> &HyraxProverInputCommitment<Bn256Point>
pub fn get_commit( &mut self, is_mask: bool, is_left_eye: bool, ) -> &HyraxProverInputCommitment<Bn256Point>
Set the field indicated by is_mask and is_left_eye to proof,
overwritting any existing value.
Sourcepub fn get_commit_left_iris(&self) -> &HyraxProverInputCommitment<Bn256Point>
pub fn get_commit_left_iris(&self) -> &HyraxProverInputCommitment<Bn256Point>
Set the left image commitment to commitment, overwritting any existing value.
Sourcepub fn get_commit_left_mask(&self) -> &HyraxProverInputCommitment<Bn256Point>
pub fn get_commit_left_mask(&self) -> &HyraxProverInputCommitment<Bn256Point>
Set the left mask commitment to commitment, overwritting any existing value.
Sourcepub fn get_commit_right_iris(&self) -> &HyraxProverInputCommitment<Bn256Point>
pub fn get_commit_right_iris(&self) -> &HyraxProverInputCommitment<Bn256Point>
Set the right image commitment to commitment, overwritting any existing value.
Sourcepub fn get_commit_right_mask(&self) -> &HyraxProverInputCommitment<Bn256Point>
pub fn get_commit_right_mask(&self) -> &HyraxProverInputCommitment<Bn256Point>
Set the right mask commitment to commitment, overwritting any existing value.
pub fn serialize(&self) -> Vec<u8> ⓘ
pub fn deserialize(bytes: &[u8]) -> Self